@@ -1,4 +1,4 @@
- #    Copyright 2003,2007 Regis Damongeot
+ #    Copyright 2003,2008 Regis Damongeot
 
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -96,7 +96,7 @@ set i18n_error_file_not_present "This file is not present in file list"
 set i18n_error_adding_ef "This file or directory  is already in excluded file list, contains already added files or directory in this list or is contained by an already added directory"
 set i18n_excluded_files_and_dir "Excluded Files And Directories"
 set i18n_file_menu "File"
-
+set i18n_need_overburn "You need to enable overburning if you want to burn all these files"
 
 
 lappend i18n_language_list "French"
@@ -104,7 +104,7 @@ if { "$language" == "French" } {
 	set i18n_step1 "Etape 1: Selection des fichiers et des dossiers"
 	set i18n_step2 "Options de gravure"
 	set i18n_burn_files_and_folders_on_a_dvd "Graver les fichiers et les dossiers sur un CD/DVD"
-	set i18n_only_create_iso9660_image "Crer une image ISO"
+	set i18n_only_create_iso9660_image "Créer une image ISO"
 	set i18n_burn_iso9660_image "Graver une image ISO"
 	set i18n_add_files "Ajouter fichiers..."
 	set i18n_add_directory "Ajouter dossier..."
@@ -112,20 +112,20 @@ if { "$language" == "French" } {
 	set i18n_clear_list "Vider la liste"
 	set i18n_excluded_files_dir "Fichiers exclus..."
 	set i18n_close "Fermer"
-	set i18n_used_space "Espace utilis:"
+	set i18n_used_space "Espace utilisé:"
 	set i18n_free_space "Espace libre:"
-	set i18n_burning_device "Priphrique:"
+	set i18n_burning_device "Périphérique:"
 	set i18n_volume_name "Nom de volume:"
 	set i18n_command "Commande:"
 	set i18n_erase_dvdrw "Effacer un DVD RW"
 	set i18n_erase_cdrw "Effacer un CD-RW"
-	set i18n_advanced_options_b "Options avances..."
-	set i18n_advanced_options_t "Options avances"
+	set i18n_advanced_options_b "Options avancées..."
+	set i18n_advanced_options_t "Options avancées"
 	set i18n_burn "Graver"
-	set i18n_filesystem_extensions "Extensions du systme de fichier:"
+	set i18n_filesystem_extensions "Extensions du système de fichier:"
 	set i18n_add_joliet_extensions "Ajouter les extensions Joliet (-J)"
 	set i18n_rock_ridge_extensions "Extensions Rock Ridge:"
-	set i18n_off "Dsactiver"
+	set i18n_off "Désactiver"
 	set i18n_rr_extensions "Extensions RR (-R)"
 	set i18n_anonymous_rr_extensions "Extensions RR anonymes (droits r--r--r-- ou +x si executable) (-r)"
 	set i18n_udf_extensions "Extensions UDF:"
@@ -137,11 +137,11 @@ if { "$language" == "French" } {
 	set i18n_overburn "Overburn (-overburn)"
 	set i18n_pad "Pad (-pad)"
 	set i18n_add_session_to_disc "Ajouter une session au disque courant (-M)"
-	set i18n_maximum_media_compatibility "Compatibilit maximum (si DVD R => cration d'un disque monosession ferm) (-dvd-compat)"
-	set i18n_monosession_cd "Crer un CD monosession/Fermer un CD multisession"
-	set i18n_multisession_cd "Crer un CD multisession/ajouter une session au CD (-multi)"
-	set i18n_eject_cd_after_burning "Ejecter le CD aprs la gravure"
-	set i18n_automaticaly_refresh_used_space "Rafraichissement automatique de l'espace disque utilis (peut prendre beaucoup de temps)"
+	set i18n_maximum_media_compatibility "Compatibilité maximum (si DVD R => création d'un disque monosession fermé) (-dvd-compat)"
+	set i18n_monosession_cd "Créer un CD monosession/Fermer un CD multisession"
+	set i18n_multisession_cd "Créer un CD multisession/ajouter une session au CD (-multi)"
+	set i18n_eject_cd_after_burning "Ejecter le CD après la gravure"
+	set i18n_automaticaly_refresh_used_space "Rafraichissement automatique de l'espace disque utilisé (peut prendre beaucoup de temps)"
 	set i18n_open "Ouvrir..."
 	set i18n_growisofs_mkisofs_output "Sortie de growisofs/mkisofs/cdrecord"
 	set i18n_update "Rafraichir"
@@ -152,31 +152,32 @@ if { "$language" == "French" } {
 	set i18n_normal_format "Formattage normal (-force)"
 	set i18n_quick_format "Formattage rapide"
 	set i18n_quick_format_cd "Formattage rapide (blank=fast)"
-	set i18n_writing_finished "Opration termine"
+	set i18n_writing_finished "Opération terminée"
 	set i18n_load_file_list "Charger une liste de fichiers"
 	set i18n_save_file_list "Sauvegarder la liste de fichiers"
-	set i18n_error_filelist_empty "La liste des fichiers  graver est vide"
+	set i18n_error_filelist_empty "La liste des fichiers à graver est vide"
 	set i18n_error "Erreur"
 	set i18n_dvd_copy "Copier un DVD"
 	set i18n_cd_copy "Copier un CD"
 	set i18n_copy "Copier"
-	set i18n_choose_source_device "Choisissez le priphrique source:"
+	set i18n_choose_source_device "Choisissez le périphérique source:"
 	set i18n_quit "Quitter"
-	set i18n_create_iso_from_dvd "Crer une image ISO  partir d'un DVD"
-	set i18n_create_iso_from_cd "Crer une image ISO  partir d'un CD"
+	set i18n_create_iso_from_dvd "Créer une image ISO à partir d'un DVD"
+	set i18n_create_iso_from_cd "Créer une image ISO à partir d'un CD"
 	set i18n_choose_target_file "Choisir le fichier cible..."
-	set i18n_create "Crer"
-	set i18n_error_target_file_ns "Fichier cible non prcis"
-	set  i18n_error_directory_already_present "Ce dossier est dj prsent dans la liste des fichiers"
-	set  i18n_quest_directory_contained "Ce dossier est dj contenu dans un autre dossier de la liste des fichiers. Voulez-vous l'ajouter tout de mme?"
-	set  i18n_quest_directory_contains "Ce dossier contient certains fichiers ou dossiers dj prsent dans la liste des fichiers. Voulez-vous l'ajouter tout de mme?"
-	set  i18n_error_file_already_present "Le fichier suivant est dj prsent dans la liste des fichiers"
-	set  i18n_quest_file_contained "Le fichier suivant est dj contenu dans un dossier de la liste des fichiers. Voulez-vous l'ajouter tout de mme?"
-	set i18n_error_directory_not_present "Ce fichier n'est pas prsent dans la liste"
-	set i18n_error_file_not_present "Ce fichier n'est pas prsent dans la liste"
-	set i18n_error_adding_ef "Ce fichier/dossier est dj dans la liste des fichiers exclus, ou bien contient des fichiers dj ajout  cette liste, ou alors est contenu dans un dossier dj prcedement ajout"
+	set i18n_create "Créer"
+	set i18n_error_target_file_ns "Fichier cible non précisé"
+	set  i18n_error_directory_already_present "Ce dossier est déjà présent dans la liste des fichiers"
+	set  i18n_quest_directory_contained "Ce dossier est déjà contenu dans un autre dossier de la liste des fichiers. Voulez-vous l'ajouter tout de même?"
+	set  i18n_quest_directory_contains "Ce dossier contient certains fichiers ou dossiers déjà présent dans la liste des fichiers. Voulez-vous l'ajouter tout de même?"
+	set  i18n_error_file_already_present "Le fichier suivant est déjà présent dans la liste des fichiers"
+	set  i18n_quest_file_contained "Le fichier suivant est déjà contenu dans un dossier de la liste des fichiers. Voulez-vous l'ajouter tout de même?"
+	set i18n_error_directory_not_present "Ce fichier n'est pas présent dans la liste"
+	set i18n_error_file_not_present "Ce fichier n'est pas présent dans la liste"
+	set i18n_error_adding_ef "Ce fichier/dossier est déjà dans la liste des fichiers exclus, ou bien contient des fichiers déjà ajouté à cette liste, ou alors est contenu dans un dossier déjà précedement ajouté"
 	set i18n_excluded_files_and_dir "Fichiers et dossiers exclus"
 	set i18n_file_menu "Fichier"
+	set i18n_need_overburn "Vous devez activer l'overburning pour pouvoir graver autant de données"
 }
 
 # German Translation by Marion Petersen <marion-petersen@gmx.de>
@@ -190,47 +191,47 @@ if { "$language" == "German" } {
 	set i18n_burn_files_and_folders_on_a_dvd "Dateien und Verzeichnisse auf eine CD/DVD brennen"
 	set i18n_only_create_iso9660_image "Nur ein ISO9660-Image erstellen"
 	set i18n_burn_iso9660_image "ISO-9660-Image brennen"
-	set i18n_add_files "Datei hinzufgen"
-	set i18n_add_directory "Ordner hinzufgen"
-	set i18n_delete_file_dir "Objekte lschen"
-	set i18n_clear_list "Liste lschen"
+	set i18n_add_files "Datei hinzufügen"
+	set i18n_add_directory "Ordner hinzufügen"
+	set i18n_delete_file_dir "Objekte löschen"
+	set i18n_clear_list "Liste löschen"
 	set i18n_excluded_files_dir "Ausnahmen"
-	set i18n_close "Schlieen"
+	set i18n_close "Schließen"
 	set i18n_used_space "Genutzter Platz:"
 	set i18n_free_space "Freier Platz:"
-	set i18n_burning_device "Gerte:"
+	set i18n_burning_device "Geräte:"
 	set i18n_volume_name "Volumen-Name:"
 	set i18n_command "Kommando:"
-	set i18n_erase_dvdrw "DVD RW lschen"
-	set i18n_erase_cdrw "CD RW lschen"
+	set i18n_erase_dvdrw "DVD RW löschen"
+	set i18n_erase_cdrw "CD RW löschen"
 	set i18n_advanced_options_b "Erweiterte Optionen"
 	set i18n_advanced_options_t "Erweiterte Optionen"
 	set i18n_burn "Brennen"
 	set i18n_filesystem_extensions "Dateisystem-Erweiterungen:"
-	set i18n_add_joliet_extensions "Joliet-Erweiterung (-J) hinzufgen"
+	set i18n_add_joliet_extensions "Joliet-Erweiterung (-J) hinzufügen"
 	set i18n_rock_ridge_extensions "Rock-Ridge-Erweiterung:"
 	set i18n_off "Aus"
 	set i18n_rr_extensions "RR-Erweiterung (-R)"
-	set i18n_anonymous_rr_extensions "Anonyme RR-Erweiterung (Alle Dateien werden auf r--r--r-- oder - falls ausfhrbar - +x gesetzt) (-r)"
+	set i18n_anonymous_rr_extensions "Anonyme RR-Erweiterung (Alle Dateien werden auf r--r--r-- oder - falls ausführbar - +x gesetzt) (-r)"
 	set i18n_udf_extensions "UDF-Erweiterung:"
 	set i18n_udf_extensions_radiobutton "UDF-Erweiterung (-udf)"
 	set i18n_dvd_video_compliant_udf_filesystem "DVD-Video-konformes UDF-Dateisystem (-dvd-video)"
-	set i18n_dvd_size "CD/DVD-Gre:"
+	set i18n_dvd_size "CD/DVD-Größe:"
 	set i18n_other_options "Andere Optionen:"
-	set i18n_burning_speed "Brenngeschwindigkeit, fr maximale Geschwindigkeit frei lassen (-speed=X):"
-	set i18n_overburn "berbrennen (-overburn)"
-	set i18n_pad "Datentrack auffllen (-pad)"
-	set i18n_add_session_to_disc "Session hinzufgen (-M)"
-	set i18n_maximum_media_compatibility "Maximale Medien-Kompatibilitt (DVD R => erstelle abgeschlossene Monosession-DVD) (-dvd-compat)"
-	set i18n_monosession_cd "Monosession-CD erstellen/Multisession-CD abschlieen"
-	set i18n_multisession_cd "Multisession-CD erstellen/Session zu CD hinzufgen (-multi)"
+	set i18n_burning_speed "Brenngeschwindigkeit, für maximale Geschwindigkeit frei lassen (-speed=X):"
+	set i18n_overburn "Überbrennen (-overburn)"
+	set i18n_pad "Datentrack auffüllen (-pad)"
+	set i18n_add_session_to_disc "Session hinzufügen (-M)"
+	set i18n_maximum_media_compatibility "Maximale Medien-Kompatibilität (DVD R => erstelle abgeschlossene Monosession-DVD) (-dvd-compat)"
+	set i18n_monosession_cd "Monosession-CD erstellen/Multisession-CD abschließen"
+	set i18n_multisession_cd "Multisession-CD erstellen/Session zu CD hinzufügen (-multi)"
 	set i18n_eject_cd_after_burning "CD nach dem Brennen auswerfen"
 	set i18n_automaticaly_refresh_used_space "Genutzten Speicherplatz automatisch aktualisieren (kann viel Zeit in Anspruch nehmen)"
-	set i18n_open "ffnen ..."
+	set i18n_open "Öffnen ..."
 	set i18n_growisofs_mkisofs_output "Ausgabe von growisofs/mkisofs/cdrecord"
 	set i18n_update "Aktualisieren"
-	set i18n_select_iso_image "ISO-Image auswhlen"
-	set i18n_erase "Lschen"
+	set i18n_select_iso_image "ISO-Image auswählen"
+	set i18n_erase "Löschen"
 	set i18n_full_format "Komplette Formatierung (-blank=full)"
 	set i18n_full_format_cd "Komplette Formatierung (blank=all)"
 	set i18n_normal_format "Normale Formatierung (-force)"
@@ -244,21 +245,21 @@ if { "$language" == "German" } {
 	set i18n_dvd_copy "DVD kopieren"
 	set i18n_cd_copy "CD kopieren"
 	set i18n_copy "Kopieren"
-	set i18n_choose_source_device "Quell-Gert auswhlen:"
+	set i18n_choose_source_device "Quell-Gerät auswählen:"
 	set i18n_quit "Verlassen"
 	set i18n_create_iso_from_dvd "ISO-Image von DVD erstellen"
 	set i18n_create_iso_from_cd "ISO-Image von CD erstellen"
-	set i18n_choose_target_file "Ziel-Datei auswhlen ..."
+	set i18n_choose_target_file "Ziel-Datei auswählen ..."
 	set i18n_create "Erstellen"
-	set i18n_error_target_file_ns "Ziel-Datei nicht ausgewhlt."
+	set i18n_error_target_file_ns "Ziel-Datei nicht ausgewählt."
 	set i18n_error_directory_already_present "Dieses Verzeichnis ist bereits in der Dateiliste enthalten"
-	set i18n_quest_directory_contained "Dieses Verzeichnis ist bereits in einem anderen Verzeichnis in der Dateiliste enthalten. Trotzdem hinzufgen?"
-	set i18n_quest_directory_contains "Dieses Verzeichnis enthlt Dateien oder Verzeichnisse, die bereits in der Dateiliste enthalten sind. Trotzdem hinzufgen?"
+	set i18n_quest_directory_contained "Dieses Verzeichnis ist bereits in einem anderen Verzeichnis in der Dateiliste enthalten. Trotzdem hinzufügen?"
+	set i18n_quest_directory_contains "Dieses Verzeichnis enthält Dateien oder Verzeichnisse, die bereits in der Dateiliste enthalten sind. Trotzdem hinzufügen?"
 	set i18n_error_file_already_present "Diese Datei ist bereits in der Dateiliste enthalten"
-	set i18n_quest_file_contained "Diese Datei ist bereits in einem der Verzeichnisse in der Dateiliste enthalten. Trotzdem hinzufgen?"
+	set i18n_quest_file_contained "Diese Datei ist bereits in einem der Verzeichnisse in der Dateiliste enthalten. Trotzdem hinzufügen?"
 	set i18n_error_directory_not_present "Dieses Verzeichnis ist nicht in der Dateiliste enthalten."
 	set i18n_error_file_not_present "Diese Datei ist nicht in der Dateiliste enthalten."
-	set i18n_error_adding_ef "Diese Datei bzw. dieses Verzeichnis ist entweder in der Liste ausgenommener Dateien enthalten, enthlt bereits zu dieser Liste hinzugefgte Dateien oder Verzeichnisse oder ist in einem bereits der Liste hinzugefgten Verzeichnisse enthalten."
+	set i18n_error_adding_ef "Diese Datei bzw. dieses Verzeichnis ist entweder in der Liste ausgenommener Dateien enthalten, enthält bereits zu dieser Liste hinzugefügte Dateien oder Verzeichnisse oder ist in einem bereits der Liste hinzugefügten Verzeichnisse enthalten."
 	set i18n_excluded_files_and_dir "Ausgenommene Dateien und Ordner"
 	set i18n_file_menu "Datei"
 }
@@ -343,19 +344,19 @@ if { "$language" == "Italian" } {
 lappend i18n_language_list "Spanish"
 if { "$language" == "Spanish" } {
 	set i18n_step1 "Paso 1: Seleccionar archivos y directorios"
-	set i18n_step2 "Paso 2: Grabacin personalizada"
+	set i18n_step2 "Paso 2: Grabación personalizada"
 	set i18n_burn_files_and_folders_on_a_dvd "Grabar archivos y directorios en el CD/DVD"
 	set i18n_only_create_iso9660_image "Solamente crear la imagen ISO9660"
 	set i18n_burn_iso9660_image "Grabar la imagen ISO9660"
-	set i18n_add_files "Aadir archivos"
-	set i18n_add_directory "Aadir directorios"
+	set i18n_add_files "Añadir archivos"
+	set i18n_add_directory "Añadir directorios"
 	set i18n_delete_file_dir "Borrar archivo"
 	set i18n_clear_list "Limpiar lista"
 	set i18n_excluded_files_dir "Excluir archivos"
 	set i18n_close "Cerrar"
 	set i18n_used_space "Espacio usado:"
 	set i18n_free_space "Espacio libre:"
-	set i18n_burning_device "Dispositivo grabacin:"
+	set i18n_burning_device "Dispositivo grabación:"
 	set i18n_volume_name "Nombre del volumen:"
 	set i18n_command "Orden:"
 	set i18n_erase_dvdrw "Borrar DVD RW"
@@ -364,28 +365,110 @@ if { "$language" == "Spanish" } {
 	set i18n_advanced_options_t "Opciones avanzadas"
 	set i18n_burn "Grabar"
 	set i18n_filesystem_extensions "Opciones detalladas:"
-	set i18n_add_joliet_extensions "Aadir Joliet (para Windows) (-J)"
+	set i18n_add_joliet_extensions "Añadir Joliet (para Windows) (-J)"
 	set i18n_rock_ridge_extensions "Rock Ridge:"
 	set i18n_off "Apagado"
 	set i18n_rr_extensions "RR (-R)"
-	set i18n_anonymous_rr_extensions "Annimo RR (todos archivos son lecture fija o ejecutable) (-r)"
+	set i18n_anonymous_rr_extensions "Anónimo RR (todos archivos son lecture fija o ejecutable) (-r)"
 	set i18n_udf_extensions "UDF:"
 	set i18n_udf_extensions_radiobutton "UDF (-udf)"
 	set i18n_dvd_video_compliant_udf_filesystem "DVD video UDF (-dvd-video)"
-	set i18n_dvd_size "Tamao de CD/DVD:"
+	set i18n_dvd_size "Tamaño de CD/DVD:"
 	set i18n_other_options "Otras opciones:"
 	set i18n_overburn "Permitir overburning (-overburn)"
 	set i18n_pad "Pad (-pad)"
-	set i18n_add_session_to_disc "Aadir sesin a disco (-M)"
-	set i18n_maximum_media_compatibility "Mximo tamao del medio (si DVD R => crear unisesin disco cerrado) (-dvd-compat)"
+	set i18n_add_session_to_disc "Añadir sesión a disco (-M)"
+	set i18n_maximum_media_compatibility "Máximo tamaño del medio (si DVD R => crear unisesión disco cerrado) (-dvd-compat)"
 	set i18n_open "Abrir..."
 	set i18n_select_iso_image "Seleccionar la imagen ISO"
 	set i18n_erase "Borrar"
 	set i18n_full_format "Formato completo (-blank=full)"
 	set i18n_full_format_cd "Formato completo (blank=all)"
 	set i18n_normal_format "Formato normal (-force)"
-	set i18n_quick_format "Formato rpido"
-	set i18n_quick_format_cd "Formato rpido (blank=fast)"
+	set i18n_quick_format "Formato rápido"
+	set i18n_quick_format_cd "Formato rápido (blank=fast)"
 	set i18n_writing_finished "Grabando completo"
 }
 
+# Hungarian translation by Sandor Lisovszki <lisovszki@gmail.com>
+# Copyright (C) 2008 Sandor Lisovszki
+# Licensed under the terms of the GPLv2 (or later)
+lappend i18n_language_list "Magyar"
+if { "$language" == "Magyar" } {
+	set i18n_step1 "Első lépés: Mappák és fájlok kiválasztása"
+	set i18n_step2 "Írás testreszabása"
+	set i18n_burn_files_and_folders_on_a_dvd "Fájlok írása CD/DVD-re"
+	set i18n_only_create_iso9660_image "Csak iso9660 képfájl készítése"
+	set i18n_burn_iso9660_image "iso9660 képfájl írása"
+	set i18n_add_files "Fájlt hozzáad"
+	set i18n_add_directory "Könyvtárt hozzáad"
+	set i18n_delete_file_dir "Fájl/Könyvtár törlés"
+	set i18n_clear_list "Lista törlése"
+	set i18n_excluded_files_dir "Kizárt fájlok..."
+	set i18n_close "Bezárás"
+	set i18n_used_space "Felhasznált terület:"
+	set i18n_free_space "Szabad terület:"
+	set i18n_burning_device "Író eszköz:"
+	set i18n_volume_name "Kötet név:"
+	set i18n_command "Parancs:"
+	set i18n_erase_dvdrw "DVD RW törlése"
+	set i18n_erase_cdrw "CD-RW törlése"
+	set i18n_advanced_options_b "Haladó beállítások..."
+	set i18n_advanced_options_t "Haladó beállítások"
+	set i18n_burn "Írás"
+	set i18n_filesystem_extensions "Fájlrendszer kiterjesztések:"
+	set i18n_add_joliet_extensions "Joliet kiterjesztés hozzáadása (-J)"
+	set i18n_rock_ridge_extensions "Rock Ridge kiterjesztések:"
+	set i18n_off "Kikapcsol"
+	set i18n_rr_extensions "RR kiterjesztések (-R)"
+	set i18n_anonymous_rr_extensions "Névtelen RR kiterjesztések (minden fájl beállítva r--r--r-- vagy +x ha futtatható) (-r)"
+	set i18n_udf_extensions "UDF kiterjesztések:"
+	set i18n_udf_extensions_radiobutton "UDF kiterjesztések (-udf)"
+	set i18n_dvd_video_compliant_udf_filesystem "DVD Video kompatibilis UDF fájlrendszer (-dvd-video)"
+	set i18n_dvd_size "CD/DVD méret:"
+	set i18n_other_options "Egyéb beállítások:"
+	set i18n_burning_speed "Írás sebessége, hagyd üresen a maximális sebesség használatához (-speed=X):"
+	set i18n_overburn "Túlírás (-overburn)"
+	set i18n_pad "Pad (-pad)"
+	set i18n_add_session_to_disc "Folyamat hozzáadása a lemezhez (-M)"
+	set i18n_maximum_media_compatibility "Maximális média kompatibilitás (ha DVD R => egyszerű folyamat készítése, bezárás) (-dvd-compat)"
+	set i18n_monosession_cd "Monosession CD készítése/Multisession CD bezárása"
+	set i18n_multisession_cd "Multisession CD készítése/folyamat csatolása CD-hez (-multi)"
+	set i18n_eject_cd_after_burning "Add ki a CD-t az írás végén"
+	set i18n_automaticaly_refresh_used_space "Automatikus felhasznált terület frissítés (sokáig eltarthat)"
+	set i18n_open "Megnyitás..."
+	set i18n_growisofs_mkisofs_output "growisofs/mkisofs/cdrecord output"
+	set i18n_update "Frissítés"
+	set i18n_select_iso_image "ISO képfájl kiválasztása"
+	set i18n_erase "Törlés"
+	set i18n_full_format "Teljes fomatálás (-blank=full)"
+	set i18n_full_format_cd "Teljes formatálás (blank=all)"
+	set i18n_normal_format "Normál formatálás (-force)"
+	set i18n_quick_format "Gyors formatálás"
+	set i18n_quick_format_cd "Gyors formatálás (blank=fast)"
+	set i18n_writing_finished "Írás befejeződött"
+	set i18n_load_file_list "Fájllista betöltése"
+	set i18n_save_file_list "fájllista mentése"
+	set i18n_error_filelist_empty "A fájllista üres"
+	set i18n_error "Hiba"
+	set i18n_dvd_copy "DVD másolás"
+	set i18n_cd_copy "CD másolás"
+	set i18n_copy "Másolás"
+	set i18n_choose_source_device "Forrás eszköz kiválasztása:"
+	set i18n_quit "Quit"
+	set i18n_create_iso_from_dvd "ISO képfájl készítése DVD-ről"
+	set i18n_create_iso_from_cd "ISO képfájl készítése CD-ről"
+	set i18n_choose_target_file "Célfájl kiválasztása..."
+	set i18n_create "Elkészítés"
+	set i18n_error_target_file_ns "Célfájl nincs megadva"
+	set i18n_error_directory_already_present "Ez a könyvtár már szerepel a fájllistában"
+	set i18n_quest_directory_contained "Ez a könyvtár már benne van egy másik könyvtárban, ami szerepel a fájllistában. Bizosan hozzá akarod adni?"
+	set i18n_quest_directory_contains "Ez a könyvtár olyan mappákat/fájlokat tartalmaz, amelyek már szerepelnek a fájllistában. Biztosan hozzá akarod adni?"
+	set i18n_error_file_already_present "A következő fájl már szerepel a fájllistában"
+	set i18n_quest_file_contained "Ez a fájl már benne van egy könyvtárban, ami szerepel a fájllistában. Biztos hozzáadod?"
+	set i18n_error_directory_not_present "Ez a könyvtár nem szerepel a fájllistában"
+	set i18n_error_file_not_present "Ez a fájl nincs benne a fájllistában"
+	set i18n_error_adding_ef "Ez a fájl vagy könyvtár már benne van egy fájllistában, már tartalmaz hozzáadott fájlokat, könyvtárakat, vagy már szerepel egy hozzáadott könyvtárban"
+	set i18n_excluded_files_and_dir "Hozzáadott fájlok és könyvtárak"
+	set i18n_file_menu "Fájl"
+}
\ No newline at end of file
